==> 2.5.zip: piwigo/language/ms_MY/common.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2013 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
/*
Language Name: Malay [MY]
Version: 2.5.0
Language URI: http://piwigo.org/ext/extension_view.php?eid=645
Author: Piwigo team
Author URI: http://piwigo.org
*/

$lang_info['language_name'] = 'Malay';
$lang_info['country'] = 'Malaysia';
$lang_info['direction'] = 'ltr';
$lang_info['code'] = 'ms';
$lang_info['zero_plural'] = true;


$lang['%d album updated'] = '%d album dikemaskini';
$lang['%d albums updated'] = '%d album-album dikemaskini';
$lang['%d comment to validate'] = '%d komen untuk mengesahkan';
$lang['%d comment'] = '%d komen';
$lang['%d comments to validate'] = '%d komen untuk mengesahkan';
$lang['%d comments'] = '%d komen-komen';
$lang['%d hit'] = '%d hit';
$lang['%d hits'] = '%d hits';
$lang['%d Kb'] = '%d Kb';
$lang['%d new comment'] = '%d komen baru';
$lang['%d new comments'] = '%d komen-komen baru';
$lang['%d new photo'] = '%d baru foto';
$lang['%d new photos'] = '%d baru foto-foto';
$lang['%d new user'] = '%d pengguna baru';
$lang['%d new users'] = '%d pengguna baru';
$lang['%d photo is also linked to current tags'] = '%d foto juga dikaitkan dengan tags semasa';
$lang['%d photo'] = '%d photo';
$lang['%d photos are also linked to current tags'] = '%d gambar juga dikaitkan dengan tags semasa';
$lang['%d photos'] = '%d foto-foto';
$lang['%d rates'] = '%d kadar-kadar';
$lang['(!) This comment requires validation'] = '(!) Komen ini memerlukan pengesahan';
$lang['... or browse your empty gallery'] = '... atau melayari galeri kosong anda';
$lang['... or please deactivate this message, I will find my way by myself'] = '... atau sila menyahaktifkan mesej ini, saya akan mencari jalan saya oleh diri saya sendiri';
$lang['A comment on your site'] = 'Satu komen di laman anda';
$lang['About Piwigo'] = 'Mengenai Piwigo';
$lang['About'] = 'Mengenai';

$lang['Interface theme'] = 'Tema antarmuka';
$lang['Invalid key'] = 'Kunci tidak cocok';
$lang['Invalid password!'] = 'kata sandi tidak cocok!';
$lang['Invalid username or email'] = 'Nama pengguna atau email yang tidak cocok';
$lang['Keyword'] = 'Kata kunci';
$lang['Kind of date'] = 'Jenis tanggal';
$lang['Language'] = 'Bahasa';
$lang['Last'] = 'Terakhir';
$lang['Last Page'] = 'Halaman terakhir';
$lang['Links'] = 'Link';
$lang['Login'] = 'Masuk';
$lang['Logout'] = 'Keluar';
$lang['Manage this user comment: %s'] = 'Atur komentar pengguna ini %s';
$lang['Manual sort order'] = 'Penyusunan manual';
$lang['Menu'] = 'Menu';
$lang['Mobile'] = 'Ponsel';
$lang['Most visited'] = 'Paling banyak dikunjungi';
$lang['N/A'] = 'Tidak tersedia';
$lang['New on %s'] = 'baru di %s';
$lang['New password'] = 'Kata sandi baru';
$lang['Filter'] = 'Saring';
$lang['Filter and display'] = 'Saring dan tampilkan';
$lang['First'] = 'Pertama';
$lang['First Page'] = 'Halaman pertama';
$lang['Forbidden'] = 'Disembunyikan';
$lang['Forgot your password?'] = 'Lupa password anda?';
$lang['Go back to the album'] = 'Kembali ke album';
$lang['Go through the gallery as a visitor'] = 'Navigasi galeri sebagai pengunjung';
$lang['Hello'] = 'Halo';
$lang['Hello %s,'] = 'Halo %s';
$lang['Hello %s, your Piwigo photo gallery is empty!'] = 'Halo %, Galeri foto Piwigo anda masih kosong! ';
$lang['Help'] = 'Bantuan';
$lang['Here are your connection settings'] = 'Ini adalah pengaturan koneksi anda';
$lang['Home'] = 'Beranda';
$lang['I want to add photos'] = 'Saya ingin menambahkan sebuah foto';
$lang['IP: %s'] = 'IP: %s';
$lang['IPTC Metadata'] = 'IPTC Metadata';
$lang['Identification'] = 'Identifikasi';
$lang['If this was a mistake, just ignore this email and nothing will happen.'] = 'Jika ini adalah kesalahan, cukup abaikan email ini dan tidak akan terjadi apa-apa.';
$lang['If you think you\'ve received this email in error, please contact us at %s'] = 'Jika anda merasa email ini merupakan kesalahan, harap hubungi kami di %s';
$lang['EXIF Metadata'] = 'EXIF Metadata';
$lang['Edit'] = 'Ubah';
$lang['Edit a comment'] = 'Ubah sebuah komentar';
$lang['Email'] = 'Email';
$lang['Email address'] = 'Alamat email';
$lang['Email address is mandatory'] = 'Alamat email ditahan';
$lang['Email address is missing. Please specify an email address.'] = 'Alamat email anda tidak aktif, mohon beri alamat yang baru';
$lang['Email: %s'] = 'Email: %s';
$lang['Empty query. No criteria has been entered.'] = 'Kolom ini kosong, Belum ada kriteria yang dimasukkan';
$lang['End-Date'] = 'Tanggal kadaluarsa';
$lang['Enter your new password below.'] = 'Masukkan kata sandi baru anda di bawah';
$lang['Enter your personnal informations'] = 'Masukkan data pribadi anda';
$lang['Error sending email'] = 'Kesalahan ketika mengirimkan email';
$lang['Expand all albums'] = 'Lebarkan semua album';
$lang['Favorites'] = 'Favorit';
$lang['File'] = 'Dokumen';
$lang['File name'] = 'Nama dokumen';
$lang['File name, A &rarr; Z'] = 'Nama dokumen, A &rarr; Z';
$lang['File name, Z &rarr; A'] = 'Nama dokumen, Z &rarr; A';
$lang['Filesize'] = 'Ukuran dokumen';
$lang['Cookies are blocked or not supported by your browser. You must enable cookies to connect.'] = 'Kukis diblokir atau tidak didukung oleh browser anda. Anda harus mengaktifkan kukis untuk masuk';
$lang['Create a new account'] = 'Membuat akun baru';
$lang['Created on'] = 'Dibuat';
$lang['Creation date'] = 'Tanggal pembuatan';
$lang['Current password is wrong'] = 'Kata sandi sekarang keliru';
$lang['Customize'] = 'Kostumisasi';
$lang['Date'] = 'Tanggal';
$lang['Date created, new &rarr; old'] = 'Tanggal pembuatan, baru &rarr; lama';
$lang['Date created, old &rarr; new'] = 'Tanggal pembuatan, lama &rarr; baru';
$lang['Date posted, new &rarr; old'] = 'Tanggal dipublikasi, baru &rarr; lama';
$lang['Date posted, old &rarr; new'] = 'Tanggal dipublikasikan, lama &rarr; baru';
$lang['Default'] = 'Standar';
$lang['Delete'] = 'Hapus';
$lang['Desktop'] = 'Deskop';
$lang['Dimensions'] = 'Dimensi';
$lang['Display'] = 'Tampilkan';
$lang['Download'] = 'unggah';
$lang['Download this file'] = 'unggah dokumen ini';
$lang['Each listed rule must be satisfied.'] = 'Tiap kriteria harus diselesaikan';
$lang['Author: %s'] = 'Penulis : %';
$lang['Auto login'] = 'Masuk otomatis';
$lang['Author'] = 'Penulis';
$lang['At least one listed rule must be satisfied.'] = 'Sekurangnya satu kategori harus diselesaikan';
$lang['Are you sure?'] = 'Apakah anda yakin?';
$lang['Any tag'] = 'Kata kunci lain';
$lang['Anti-flood system : please wait for a moment before trying to post another comment'] = 'Sistem penahan : harap tunggu sebentar sebelum memposting komentar yang baru';
$lang['An administrator must authorize your comment before it is visible.'] = 'Seorang pengelola harus mengautorisasi komentar anda sebelum dilihat khalayak umum';
$lang['All tags'] = 'Semua kata kunci';
$lang['All'] = 'Semua';
$lang['Albums'] = 'Album';
$lang['Album: %s'] = 'Album: %s';
$lang['Album results for'] = 'Hasil album untuk';
$lang['Administration'] = 'Pengelolaan';
$lang['Album'] = 'Album';
$lang['Admin: %s'] = 'Pengelola: %s';
$lang['Add a comment'] = 'Tambahkan sebuah komentar';
$lang['Accelerate diaporama speed'] = 'Tingkatkan kecepatan gambar geser';
$lang['2small'] = 'XXS - Kecil';
$lang['%d rate'] = '%d rating';
?>

==> 14.5.0.zip: piwigo/language/ms_MY/common.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+
/*
Language Name: Malay [MY]
Version: auto
Language URI: http://piwigo.org/ext/extension_view.php?eid=645
Author: Piwigo team
Author URI: http://piwigo.org
*/

$lang_info['language_name'] = 'Malay';
$lang_info['country'] = 'Malaysia';
$lang_info['direction'] = 'ltr';
$lang_info['code'] = 'ms';
$lang_info['zero_plural'] = true;


$lang['%d album updated'] = '%d album dikemaskini';
$lang['%d albums updated'] = '%d album-album dikemaskini';
$lang['%d comment to validate'] = '%d komen untuk mengesahkan';
$lang['%d comment'] = '%d komen';
$lang['%d comments to validate'] = '%d komen untuk mengesahkan';
$lang['%d comments'] = '%d komen-komen';
$lang['%d hit'] = '%d hit';
$lang['%d hits'] = '%d hits';
$lang['%d Kb'] = '%d Kb';
$lang['%d new comment'] = '%d komen baru';
$lang['%d new comments'] = '%d komen-komen baru';
$lang['%d new photo'] = '%d baru foto';
$lang['%d new photos'] = '%d baru foto-foto';
$lang['%d new user'] = '%d pengguna baru';
$lang['%d new users'] = '%d pengguna baru';
$lang['%d photo is also linked to current tags'] = '%d foto juga dikaitkan dengan tags semasa';
$lang['%d photo'] = '%d photo';
$lang['%d photos are also linked to current tags'] = '%d gambar juga dikaitkan dengan tags semasa';
$lang['%d photos'] = '%d foto-foto';
$lang['%d rates'] = '%d kadar-kadar';
$lang['(!) This comment requires validation'] = '(!) Komen ini memerlukan pengesahan';
$lang['... or browse your empty gallery'] = '... atau melayari galeri kosong anda';
$lang['... or please deactivate this message, I will find my way by myself'] = '... atau sila menyahaktifkan mesej ini, saya akan mencari jalan saya oleh diri saya sendiri';
$lang['A comment on your site'] = 'Satu komen di laman anda';
$lang['About Piwigo'] = 'Mengenai Piwigo';
$lang['About'] = 'Mengenai';

$lang['Invalid key'] = 'Kunci tidak cocok';
$lang['Invalid password!'] = 'kata sandi tidak cocok!';
$lang['Invalid username or email'] = 'Nama pengguna atau email yang tidak cocok';
$lang['Keyword'] = 'Kata kunci';
$lang['Kind of date'] = 'Jenis tanggal';
$lang['Language'] = 'Bahasa';
$lang['Last'] = 'Terakhir';
$lang['Last Page'] = 'Halaman terakhir';
$lang['Links'] = 'Link';
$lang['Login'] = 'Masuk';
$lang['Logout'] = 'Keluar';
$lang['Manage this user comment: %s'] = 'Atur komentar pengguna ini %s';
$lang['Manual sort order'] = 'Penyusunan manual';
$lang['Menu'] = 'Menu';
$lang['Mobile'] = 'Ponsel';
$lang['Most visited'] = 'Paling banyak dikunjungi';
$lang['N/A'] = 'Tidak tersedia';
$lang['New on %s'] = 'baru di %s';
$lang['New password'] = 'Kata sandi baru';
$lang['Filter'] = 'Saring';
$lang['Filter and display'] = 'Saring dan tampilkan';
$lang['First'] = 'Pertama';
$lang['First Page'] = 'Halaman pertama';
$lang['Forbidden'] = 'Disembunyikan';
$lang['Forgot your password?'] = 'Lupa password anda?';
$lang['Go back to the album'] = 'Kembali ke album';
$lang['Go through the gallery as a visitor'] = 'Navigasi galeri sebagai pengunjung';
$lang['Hello'] = 'Halo';
$lang['Hello %s,'] = 'Halo %s';
$lang['Hello %s, your Piwigo photo gallery is empty!'] = 'Halo %, Galeri foto Piwigo anda masih kosong! ';
$lang['Help'] = 'Bantuan';
$lang['Here are your connection settings'] = 'Ini adalah pengaturan koneksi anda';
$lang['Home'] = 'Beranda';
$lang['I want to add photos'] = 'Saya ingin menambahkan sebuah foto';
$lang['IP: %s'] = 'IP: %s';
$lang['IPTC Metadata'] = 'IPTC Metadata';
$lang['Identification'] = 'Identifikasi';
$lang['If this was a mistake, just ignore this email and nothing will happen.'] = 'Jika ini adalah kesalahan, cukup abaikan email ini dan tidak akan terjadi apa-apa.';
$lang['If you think you\'ve received this email in error, please contact us at %s'] = 'Jika anda merasa email ini merupakan kesalahan, harap hubungi kami di %s';
$lang['EXIF Metadata'] = 'EXIF Metadata';
$lang['Edit'] = 'Ubah';
$lang['Edit a comment'] = 'Ubah sebuah komentar';
$lang['Email'] = 'Email';
$lang['Email address'] = 'Alamat email';
$lang['Email address is mandatory'] = 'Alamat email ditahan';
$lang['Email address is missing. Please specify an email address.'] = 'Alamat email anda tidak aktif, mohon beri alamat yang baru';
$lang['Email: %s'] = 'Email: %s';
$lang['Empty query. No criteria has been entered.'] = 'Kolom ini kosong, Belum ada kriteria yang dimasukkan';
$lang['End-Date'] = 'Tanggal kadaluarsa';
$lang['Enter your new password below.'] = 'Masukkan kata sandi baru anda di bawah';
$lang['Enter your personnal informations'] = 'Masukkan data pribadi anda';
$lang['Error sending email'] = 'Kesalahan ketika mengirimkan email';
$lang['Expand all albums'] = 'Lebarkan semua album';
$lang['Favorites'] = 'Favorit';
$lang['File'] = 'Dokumen';
$lang['File name'] = 'Nama dokumen';
$lang['File name, A &rarr; Z'] = 'Nama dokumen, A &rarr; Z';
$lang['File name, Z &rarr; A'] = 'Nama dokumen, Z &rarr; A';
$lang['Filesize'] = 'Ukuran dokumen';
$lang['Cookies are blocked or not supported by your browser. You must enable cookies to connect.'] = 'Kukis diblokir atau tidak didukung oleh browser anda. Anda harus mengaktifkan kukis untuk masuk';
$lang['Create a new account'] = 'Membuat akun baru';
$lang['Created on'] = 'Dibuat';
$lang['Creation date'] = 'Tanggal pembuatan';
$lang['Current password is wrong'] = 'Kata sandi sekarang keliru';
$lang['Customize'] = 'Kostumisasi';
$lang['Date'] = 'Tanggal';
$lang['Date created, new &rarr; old'] = 'Tanggal pembuatan, baru &rarr; lama';
$lang['Date created, old &rarr; new'] = 'Tanggal pembuatan, lama &rarr; baru';
$lang['Date posted, new &rarr; old'] = 'Tanggal dipublikasi, baru &rarr; lama';
$lang['Date posted, old &rarr; new'] = 'Tanggal dipublikasikan, lama &rarr; baru';
$lang['Default'] = 'Standar';
$lang['Delete'] = 'Hapus';
$lang['Desktop'] = 'Deskop';
$lang['Dimensions'] = 'Dimensi';
$lang['Display'] = 'Tampilkan';
$lang['Download'] = 'unggah';
$lang['Download this file'] = 'unggah dokumen ini';
$lang['Each listed rule must be satisfied.'] = 'Tiap kriteria harus diselesaikan';
$lang['Author: %s'] = 'Penulis : %';
$lang['Auto login'] = 'Masuk otomatis';
$lang['Author'] = 'Penulis';
$lang['At least one listed rule must be satisfied.'] = 'Sekurangnya satu kategori harus diselesaikan';
$lang['Are you sure?'] = 'Apakah anda yakin?';
$lang['Any tag'] = 'Kata kunci lain';
$lang['Anti-flood system : please wait for a moment before trying to post another comment'] = 'Sistem penahan : harap tunggu sebentar sebelum memposting komentar yang baru';
$lang['An administrator must authorize your comment before it is visible.'] = 'Seorang pengelola harus mengautorisasi komentar anda sebelum dilihat khalayak umum';
$lang['All tags'] = 'Semua kata kunci';
$lang['All'] = 'Semua';
$lang['Albums'] = 'Album';
$lang['Album: %s'] = 'Album: %s';
$lang['Album results for'] = 'Hasil album untuk';
$lang['Administration'] = 'Pengelolaan';
$lang['Album'] = 'Album';
$lang['Admin: %s'] = 'Pengelola: %s';
$lang['Add a comment'] = 'Tambahkan sebuah komentar';
$lang['Accelerate diaporama speed'] = 'Tingkatkan kecepatan gambar geser';
$lang['2small'] = 'XXS - Kecil';
$lang['%d rate'] = '%d rating';
?>
